@@ -2,7 +2,7 @@ package LWP::Protocol::http;
 
 use strict;
 
-our $VERSION = '6.32';
+our $VERSION = '6.33';
 
 require HTTP::Response;
 require HTTP::Status;
@@ -30,7 +30,7 @@ sub _new_socket
 					Proto    => 'tcp',
 					Timeout  => $timeout,
 					KeepAlive => !!$self->{ua}{conn_cache},
-					SendTE    => $self->{ua}->send_te,
+					SendTE    => $self->{ua}{send_te},
 					$self->_extra_sock_opts($host, $port),
 				       );
 
